summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--QMTest/TestSCons.py2
-rw-r--r--SConstruct2
-rw-r--r--test/update-release-info/update-release-info.py10
3 files changed, 7 insertions, 7 deletions
diff --git a/QMTest/TestSCons.py b/QMTest/TestSCons.py
index 02fd669..17a2018 100644
--- a/QMTest/TestSCons.py
+++ b/QMTest/TestSCons.py
@@ -33,7 +33,7 @@ from TestCommon import __all__
default_version = '2.1.0.alpha.yyyymmdd'
-copyright_years = '2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010'
+copyright_years = '2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011'
python_version_unsupported = (2, 3, 0)
python_version_deprecated = (2, 4, 0)
diff --git a/SConstruct b/SConstruct
index 0a8e93b..34ee6ae 100644
--- a/SConstruct
+++ b/SConstruct
@@ -5,7 +5,7 @@
# When this gets changed, you must also change the copyright_years string
# in QMTest/TestSCons.py so the test scripts look for the right string.
-copyright_years = '2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010'
+copyright_years = '2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011'
# This gets inserted into the man pages to reflect the month of release.
month_year = 'MONTH YEAR'
diff --git a/test/update-release-info/update-release-info.py b/test/update-release-info/update-release-info.py
index db2f5d1..dfcd236 100644
--- a/test/update-release-info/update-release-info.py
+++ b/test/update-release-info/update-release-info.py
@@ -69,13 +69,13 @@ combo_strings = [
"""version_tuple = (2, 0, 0, 'final', 0)
""",
# Index 5: bad release date
-"""release_date = (2010, 12)
+"""release_date = (2011, 12)
""",
# Index 6: release date (hhhh, mm, dd)
-"""release_date = (2010, 12, 21)
+"""release_date = (2011, 12, 21)
""",
# Index 7: release date (hhhh, mm, dd, hh, mm, ss)
-"""release_date = (2010, 12, 21, 12, 21, 12)
+"""release_date = (2011, 12, 21, 12, 21, 12)
""",
]
@@ -114,7 +114,7 @@ combo_fail(0, 1, 2, stdout =
combo_strings[0] = combo_strings[1] + combo_strings[2] + combo_strings[3]
combo_fail(0, 5, stdout =
"""ERROR: Invalid release date (2010, 12)
""")
def pave(path):
@@ -213,7 +213,7 @@ These files are a part of 33.22.11:
# should get Python floors from TestSCons module.
test.must_match(TestSCons, """
-copyright_years = '2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010'
+copyright_years = '2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011'
default_version = '2.0.0.alpha.yyyymmdd'
python_version_unsupported = (2, 3)
python_version_deprecated = (2, 4)
@@ -114,7 +114,7 @@ combo_fail(0, 1, 2, stdout =
combo_strings[0] = combo_strings[1] + combo_strings[2] + combo_strings[3]
combo_fail(0, 5, stdout =
-"""ERROR: Invalid release date (2010, 12)
+"""ERROR: Invalid release date (2011, 12)
""")
def pave(path):